# https://www.vcard.link/

# https://blog.csdn.net/luzeqiang/article/details/7616893
# https://blog.csdn.net/mingliuboy/article/details/6743703
# https://blog.csdn.net/zjx2014430/article/details/41548991
# https://www.iteye.com/blog/freesoftman-622705

# https://www.cnblogs.com/LXP-Never/p/11093896.html
# https://docs.python.org/zh-cn/3/library/argparse.html

from .read_file import analysis
from .command import makeVcard

__all__ = [
    "analysis"
    "makeVcard"
]


__name__ = "make_vcard"
__author__ = "antianshi"
__version__ = "1.0.0"
